References
===========


.. [Evans, Winfree 2013] Evans, C.G., Winfree, E., 2013. DNA Sticky End Design and Assignment for Robust Algorithmic Self-assembly, in: DNA Computing and Molecular Programming, Lecture Notes in Computer Science. Presented at the International Workshop on DNA-Based Computers, Springer, Cham, pp. 61–75. https://doi.org/10.1007/978-3-319-01928-4_5

.. [Evans, Winfree 2018] Evans, C.G., Winfree, E., 2018. Optimizing Tile Set Size While Preserving Proofreading with a DNA Self-assembly Compiler, in: DNA 2018, LNCS. D. Doty and H. Dietz, pp. 37–54.
